import httpx
import peewee

from data_collector import settings


def get_db():
    return peewee.SqliteDatabase(settings.DATABASE)


class Event(peewee.Model):
    title = peewee.CharField()
    start_timestamp = peewee.IntegerField()
    end_timestamp = peewee.IntegerField()
    description = peewee.TextField()
    url = peewee.CharField()
    location = peewee.CharField()
    published = peewee.BooleanField()
    image_path = peewee.CharField()

    class Meta:
        database = get_db()
        indexes = ((("title", "start_timestamp", "end_timestamp", "url"), True),)

    def publish(self):
        payload = {
            "title": self.title,
            "start_datetime": self.start_timestamp,
            "end_datetime": self.end_timestamp,
            "description": self.description,
        }

        place_id_by_location = {
            "Teatro Polytheama": (1, "polytheama"),
            "Sala Glória Rocha do Centro das Artes": (3, "gloria-rocha"),
        }
        place_id, tag = place_id_by_location.get(self.location) or (None, None)
        if place_id:
            payload["place_id"] = place_id
            payload["tags"] = ["jundiaí", tag]

        with open(f"{settings.IMAGES_STORE}{self.image_path}", "rb") as image_file:
            files = {"image": image_file}
            response = httpx.post(settings.GANCIO_API_URL, data=payload, files=files)

            if response.status_code == 200:
                self.published = True
                self.save()
                print(f"{self.title} published")
            else:
                print(
                    f"Fail to publish {self.title} ({response.status_code} {response.text})"
                )


def initialize_db():
    db = get_db()
    db.connect(reuse_if_open=True)
    db.create_tables(
        [
            Event,
        ]
    )
    return db
