import re

import httpx
import peewee
from itemadapter import ItemAdapter
from scrapy.exceptions import DropItem

from data_collector import settings
from data_collector.models import Event, initialize_db


class DataCollectorPipeline:
    def open_spider(self, spider):
        self.db = initialize_db()

    def process_item(self, item, spider):
        image_path = item["images"][0]["path"] if item["images"] else None
        location = re.sub(r"\s", " ", item["location"])

        event = Event(
            title=item["title"],
            start_timestamp=item["start_datetime"].timestamp(),
            end_timestamp=item["end_datetime"].timestamp(),
            description=item["description"],
            url=item["url"],
            location=location,
            published=False,
            image_path=image_path,
        )
        try:
            event.save()
        except peewee.IntegrityError:
            # Event was added before
            raise DropItem("Already scrapped before")

        return item

    def close_spider(self, spider):
        self.db.close()
