import re
from datetime import datetime

import scrapy


class CulturaJundiaiSpider(scrapy.Spider):
    name = "cultura_jundiai"
    allowed_domains = ["cultura.jundiai.sp.gov.br"]
    start_urls = ["https://cultura.jundiai.sp.gov.br/agenda-cultural/"]
    date_regex = r"(?P<date>\d{2}\/\d{2}\/\d{4}).*(?P<start_time>\d{2}:\d{2}).*(?P<end_time>\d{2}:\d{2})"

    def parse(self, response):
        for event in response.css(".noticia-lista"):
            event_date = event.css(".data-lista p::text").get()

            date_search = re.search(self.date_regex, event_date)
            if date_search:
                date = date_search.groupdict()["date"]
                start_time = date_search.groupdict()["start_time"]
                start_datetime = datetime.strptime(
                    f"{date} {start_time}", "%d/%m/%Y %H:%M"
                )
                end_time = date_search.groupdict()["end_time"]
                end_datetime = datetime.strptime(f"{date} {end_time}", "%d/%m/%Y %H:%M")

                event_data = {
                    "title": event.css(".titulo-lista::text").get(),
                    "start_datetime": start_datetime,
                    "end_datetime": end_datetime,
                    "url": event.css("a::attr(href)").get(),
                    "location": event.css(".resumo-lista::text").get(),
                    "tags": [
                        "jundiaí",
                    ],
                }
                yield scrapy.Request(
                    event_data["url"],
                    callback=self.parse_event,
                    cb_kwargs={"event_data": event_data},
                )

        for page_url in response.css("#paginacao a::attr(href)").getall():
            yield scrapy.Request(page_url)

    def parse_event(self, response, event_data):
        image = response.xpath(
            '//meta[@property="og:image" and @content != ""]/@content'
        ).get()
        event_data["image_urls"] = [
            image,
        ]

        event_data["description"] = response.css("article").get()

        yield event_data
